utils library

Classes

Colors
ElevationOverlay
A utility class for dealing with the overlay color needed to indicate elevation of surfaces.
NullWidget
ShapeBorderTween
An interpolation between two ShapeBorders.

Functions

lerpBool(bool? a, bool? b, double t) → bool?
lerpDouble(num? a, num? b, double t) → double?
Linearly interpolate between two numbers, a and b, by an extrapolation factor t.
lerpEnum<T>(T? a, T? b, double t) → T?
lerpInt(int? a, int? b, double t) → int?
Linearly interpolate between two integers.
radians(double degrees) → double