AlertThemeDefaults class

Inheritance
Mixed-in types
Annotations

Constructors

AlertThemeDefaults(BuildContext context, [AlertThemeData? other])

Properties

appTheme → ThemeData
no setterinherited
colorTheme → ColorThemeDefaults
no setterinherited
context → BuildContext
final
curve → Curve
The curve to apply when animating the parameters of alert widget.
finalinherited
dangerStyle → AlertStyleByVariant
The AlertStyle to be applied to the alert widget
finalinherited
duration → Duration
The duration over which to animate the parameters of alert widget.
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
infoStyle → AlertStyleByVariant
The AlertStyle to be applied to the alert widget
finalinherited
isDark → bool
no setterinherited
isLight → bool
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
style → AlertStyle
The AlertStyle to be applied to the alert widget
no setteroverride
successStyle → AlertStyleByVariant
The AlertStyle to be applied to the alert widget
finalinherited
textTheme → TextTheme
no setterinherited
type → Object
The extension's type.
no setterinherited
variantStyle → AlertStyleByVariant
The AlertStyle to be applied to the alert widget
finalinherited
warningStyle → AlertStyleByVariant
The AlertStyle to be applied to the alert widget
finalinherited

Methods

copyWith({Curve? curve, Duration? duration, AlertStyle? style, AlertStyleByVariant? variantStyle, AlertStyleByVariant? dangerStyle, AlertStyleByVariant? warningStyle, AlertStyleByVariant? successStyle, AlertStyleByVariant? infoStyle}) → AlertThemeData
Creates a copy of this AlertThemeData but with the given fields replaced with the new values.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
lerp(covariant ThemeExtension<AlertThemeData>? other, double t) → AlertThemeData
Linearly interpolate with another ThemeExtension object.
inherited
merge(AlertThemeData? other) → AlertThemeData
Creates a copy of this AlertThemeData but with the given fields replaced with the new values.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toMap() → Map<String, dynamic>
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringShort() → String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited