AnchorThemeData class

Defines the visual properties of Anchor.

Descendant widgets obtain the current AnchorThemeData object using AnchorTheme.of(context). Instances of AnchorThemeData can be customized with AnchorThemeData.copyWith or AnchorThemeData.merge.

Inheritance
Mixed-in types
Implementers
Annotations

Constructors

AnchorThemeData({required Curve curve, required Duration duration, required AnchorStyle style})
Creates a theme data that can be used for AnchorTheme.
const
AnchorThemeData.defaults(BuildContext context)
A AnchorThemeData with default values.
factory
AnchorThemeData.from([AnchorThemeData? other])
Creates a AnchorThemeData from another one that probably null.

Properties

curve → Curve
The curve to apply when animating the parameters of anchor widget.
final
duration → Duration
The duration over which to animate the parameters of anchor widget.
final
hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
style → AnchorStyle
The AnchorStyle to be applied to the anchor widget
final
type → Object
The extension's type.
no setterinherited

Methods

copyWith({Curve? curve, Duration? duration, AnchorStyle? style}) → AnchorThemeData
Creates a copy of this AnchorThemeData but with the given fields replaced with the new values.
override
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
override
lerp(covariant ThemeExtension<AnchorThemeData>? other, double t) → AnchorThemeData
Linearly interpolate with another ThemeExtension object.
override
merge(AnchorThemeData? other) → AnchorThemeData
Creates a copy of this AnchorThemeData but with the given fields replaced with the new values.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toMap() → Map<String, dynamic>
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringShort() → String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override

Constants

fallback → const AnchorThemeData
An AnchorThemeData with some reasonable default values.