AnimatedCheckmark class

Inheritance

Constructors

AnimatedCheckmark({Key? key, Color? color, Color? fill, double? weight, double? padding, ShapeBorder? shape, StrokeStyle? style, double? size, bool? value = true, Duration duration = const Duration(milliseconds: 200), Curve curve = Curves.linear})
const

Properties

color → Color?
Color of the checkmark.
final
curve → Curve
The curve to apply when animating the parameters of this container.
finalinherited
duration → Duration
The duration over which to animate the parameters of this container.
finalinherited
fill → Color?
Color of the fill background.
final
hashCode → int
The hash code for this object.
no setterinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onEnd → VoidCallback?
Called every time an animation completes.
finalinherited
padding → double?
Padding to the outer.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shape → ShapeBorder?
Defaults to RoundedRectangleBorder
final
size → double?
Expand to parent if the value is Size.zero.
final
style → StrokeStyle?
Defaults to StrokeStyle.sharp.
final
value → bool?
Whether to show the checkmark.
final
weight → double?
Stroke width of the checkmark.
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → AnimatedCheckmarkState
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited