AnimatedIcon class

Inheritance

Constructors

AnimatedIcon({Key? key, Color? color, double? opacity, double? size, double? scale, double? rotation, bool flipX = false, bool flipY = false, Duration duration = const Duration(milliseconds: 200), Curve curve = Curves.linear, required IconData icon})
const

Properties

color → Color?
Color of the checkmark.
final
curve → Curve
final
duration → Duration
final
flipX → bool
final
flipY → bool
final
hashCode → int
The hash code for this object.
no setterinherited
icon → IconData
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
opacity → double?
Color of the checkmark.
final
rotation → double?
Stroke width of the checkmark.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scale → double?
Stroke width of the checkmark.
final
size → double?
Expand to parent if the value is Size.zero.
final

Methods

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited