AnimatedIconTheme class

A widget that animates the icon theme data implicitly.

Inheritance

Constructors

AnimatedIconTheme({Key? key, Curve curve = Curves.linear, Duration duration = const Duration(milliseconds: 200), required IconThemeData data, required Widget child})
Creates an animated icon theme
const

Properties

child → Widget
The widget below this widget in the tree.
final
curve → Curve
The curve to apply when animating the parameters of this container.
finalinherited
data → IconThemeData
The color, opacity, and size to use for icons in this subtree.
final
duration → Duration
The duration over which to animate the parameters of this container.
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onEnd → VoidCallback?
Called every time an animation completes.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → AnimatedWidgetBaseState<AnimatedIconTheme>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

merge({Key? key, Curve curve = Curves.linear, Duration duration = const Duration(milliseconds: 200), IconThemeData? data, required Widget child}) → Widget
Creates an AnimatedIconTheme that controls the style of descendant widgets, and merges in the current AnimatedIconTheme, if any.