AvatarStyle class

The style to be applied to avatar widget

Mixed-in types
Annotations

Constructors

AvatarStyle({double? size, BoxShape? shape, EdgeInsetsGeometry? margin, Clip? clipBehavior, Color? shadowColor, double? elevation, TextStyle? foregroundStyle, Color? foregroundColor, double? foregroundOpacity, int? foregroundAlpha, double? foregroundSpacing, Color? backgroundColor, double? backgroundOpacity, int? backgroundAlpha, Color? borderColor, double? borderOpacity, int? borderAlpha, double? borderWidth, BorderRadius? borderRadius, BorderStyle? borderStyle})
Create a raw avatar's style
const
AvatarStyle.from(AvatarStyle? other)
Create a avatar's style from another style

Properties

backgroundAlpha → int?
Alpha to be apply to backgroundColor.
final
backgroundColor → Color?
Color to be used for the avatar's background.
final
backgroundOpacity → double?
Opacity to be apply to backgroundColor.
final
borderAlpha → int?
Alpha to be apply to borderColor.
final
borderColor → Color?
Color to be used for the avatar's border.
final
borderOpacity → double?
Opacity to be apply to borderColor.
final
borderRadius → BorderRadius?
The radii for each corner of the avatar's border.
final
borderStyle → BorderStyle?
The style of this side of the avatar's border.
final
borderWidth → double?
The width of this side of the avatar's border, in logical pixels.
final
clipBehavior → Clip?
The avatar's content will be clipped (or not) according to this option.
final
effectiveBackgroundColor → Color?
Computed background color with opacity and alpha
no setter
effectiveBorderColor → Color?
Computed border color with opacity and alpha
no setter
effectiveForegroundColor → Color?
Computed foreground color with opacity and alpha
no setter
effectiveForegroundStyle → TextStyle
Computed foreground text style with foreground color
no setter
effectiveSize → Size
A square Size from size dimension
no setter
elevation → double?
The avatar's z-coordinate relative to the parent at which to place this physical object.
final
foregroundAlpha → int?
Alpha to be apply to foregroundColor.
final
foregroundColor → Color?
The color to be applied to the avatar's label, icon, and checkmark
final
foregroundOpacity → double?
Opacity to be apply to foregroundColor.
final
foregroundSpacing → double?
How much space to place between avatar's foreground widget in a run in the main axis.
final
foregroundStyle → TextStyle?
The style to be applied to the avatar's label.
final
hashCode → int
The hash code for this object.
no setteroverride
margin → EdgeInsetsGeometry?
Empty space to surround the outside avatar widget.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shadowColor → Color?
When elevation is non zero the color to use for the avatar's shadow color.
final
shape → BoxShape?
The type of avatar's shape.
final
size → double?
The size of the avatar
final

Methods

copyWith({double? size, BoxShape? shape, EdgeInsetsGeometry? margin, Clip? clipBehavior, Color? shadowColor, double? elevation, TextStyle? foregroundStyle, Color? foregroundColor, double? foregroundOpacity, int? foregroundAlpha, double? foregroundSpacing, Color? backgroundColor, double? backgroundOpacity, int? backgroundAlpha, Color? borderColor, double? borderOpacity, int? borderAlpha, double? borderWidth, BorderRadius? borderRadius, BorderStyle? borderStyle}) → AvatarStyle
Creates a copy of this AvatarStyle but with the given fields replaced with the new values.
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
override
merge(AvatarStyle? other) → AvatarStyle
Creates a copy of this AvatarStyle but with the given fields replaced with the new values.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toMap() → Map<String, dynamic>
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringShort() → String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override

Static Methods

lerp(AvatarStyle? a, AvatarStyle? b, double t) → AvatarStyle?
Linearly interpolate between two icon theme data objects.

Constants

defaults → const AvatarStyle
An AvatarStyle with some reasonable default values.