Button class

Buttons allow users to take actions, and make choices, with a single tap

Inheritance
Implementers

Constructors

Button({Key? key, bool loading = false, bool disabled = false, bool autofocus = false, FocusNode? focusNode, VoidCallback? onPressed, ButtonEventController? eventsController, Curve? curve, Duration? duration, ButtonStyle? style, ButtonVariant? variant, ButtonSeverity? severity, String? tooltip, Widget? leading, Widget? trailing, required Widget child})
Create a button
const
Button.block({Key? key, CrossAxisAlignment? alignChildren, MainAxisAlignment? justifyChildren, bool expanded = true, bool loading = false, bool disabled = false, bool autofocus = false, FocusNode? focusNode, VoidCallback? onPressed, ButtonEventController? eventsController, Curve? curve, Duration? duration, ButtonVariant? variant, ButtonSeverity? severity, ButtonStyle? style, String? tooltip, Widget? leading, Widget? trailing, required Widget child})
Create a block button
Button.icon({Key? key, BoxShape shape = BoxShape.circle, double? size, bool loading = false, bool disabled = false, bool autofocus = false, FocusNode? focusNode, VoidCallback? onPressed, ButtonEventController? eventsController, Curve? curve, Duration? duration, ButtonVariant? variant, ButtonSeverity? severity, ButtonStyle? style, String? tooltip, Widget? leading, Widget? trailing, required Widget child})
Create an icon button

Properties

additionalStyle → ButtonStyle?
Additional style to be merge with style
final
autofocus → bool
True if this widget will be selected as the initial focus when no other node in its scope is currently focused.
final
child → Widget
The widget below this widget in the tree.
final
curve → Curve?
The curve to apply when animating the parameters of this widget.
final
disabled → bool
Whether or not this button is disabled for input.
final
duration → Duration?
The duration over which to animate the parameters of this widget.
final
effectiveStyle → dynamic
The style merged with additionalStyle
no setter
eventsController → ButtonEventController?
Used by widgets that expose their internal event for the sake of extensions that add support for additional events.
final
focusNode → FocusNode?
An optional focus node to use as the focus node for this widget.
final
hashCode → int
The hash code for this object.
no setterinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
leading → Widget?
A custom widget to display prior to the button's child.
final
loading → bool
Whether or not this button is in loading state.
final
onPressed → VoidCallback?
Called when the user taps the button.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
severity → ButtonSeverity?
Type of the button severity
final
style → ButtonStyle?
The style to be applied to the button.
final
tooltip → String?
Tooltip string to be used for the body area of the button.
final
trailing → Widget?
A custom widget to display next to the button's child.
final
variant → ButtonVariant?
Type of the button variant
final

Methods

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited