ChipStyle class

The style to be applied to chip widget

Inheritance
Implementers
Annotations

Constructors

ChipStyle({SheetSeverity? severity, SheetVariant? variant, double? height, EdgeInsetsGeometry? margin, EdgeInsetsGeometry? padding, Clip? clipBehavior, bool? overlayDisabled, Color? overlayColor, Color? shadowColor, Color? surfaceTint, double? elevation, TextStyle? foregroundStyle, Color? foregroundColor, double? foregroundOpacity, int? foregroundAlpha, double? foregroundSpacing, bool? foregroundLoosen, bool? foregroundExpanded, CrossAxisAlignment? foregroundAlign, MainAxisAlignment? foregroundJustify, Color? backgroundColor, double? backgroundOpacity, int? backgroundAlpha, Color? borderColor, double? borderOpacity, int? borderAlpha, double? borderWidth, BorderRadius? borderRadius, BorderStyle? borderStyle, Color? iconColor, double? iconOpacity, double? iconSize, Color? checkmarkColor, double? checkmarkSize, double? checkmarkWeight, StrokeStyle? checkmarkStyle, AvatarStyle? avatarStyle})
Create a raw chip's style
const
ChipStyle.from(ChipStyle? other)
Create a chip's style from another style

Properties

alignment → Alignment?
Align the child within the sheet.
finalinherited
avatarStyle → AvatarStyle?
The style to be applied to the avatar
final
backgroundAlpha → int?
Alpha to be apply to backgroundColor.
finalinherited
backgroundColor → Color?
Color to be used for the sheet's background.
finalinherited
backgroundOpacity → double?
Opacity to be apply to backgroundColor.
finalinherited
borderAlpha → int?
Alpha to be apply to borderColor.
finalinherited
borderColor → Color?
Color to be used for the sheet's border.
finalinherited
borderOpacity → double?
Opacity to be apply to borderColor.
finalinherited
borderRadius → BorderRadius?
The radii for each corner of the sheet's border.
finalinherited
borderStyle → BorderStyle?
The style of this side of the sheet's border.
finalinherited
borderWidth → double?
The width of this side of the sheet's border, in logical pixels.
finalinherited
checkmarkColor → Color?
The Color to be apply to the checkmark.
final
checkmarkSize → double?
Defaults to ChipStyle.defaultCheckmarkSize.
final
checkmarkStyle → StrokeStyle?
Defaults to StrokeStyle.sharp.
final
checkmarkWeight → double?
Stroke width of the checkmark.
final
clipBehavior → Clip?
The sheet's content will be clipped (or not) according to this option.
finalinherited
elevation → double?
The sheet's z-coordinate relative to the parent at which to place this physical object.
finalinherited
foregroundAlign → CrossAxisAlignment?
Cross axis alignment of the foreground widget
finalinherited
foregroundAlpha → int?
Alpha to be apply to foregroundColor.
finalinherited
foregroundColor → Color?
The color to be applied to the sheet's label, and icon
finalinherited
foregroundExpanded → bool?
Whether the foreground widget is expanded or not
finalinherited
foregroundJustify → MainAxisAlignment?
Main axis alignment of the foreground widget
finalinherited
foregroundLoosen → bool?
Whether the spacing is forced to child with no leading or trailing.
finalinherited
foregroundOpacity → double?
Opacity to be apply to foregroundColor.
finalinherited
foregroundSpacing → double?
How much space to place between sheet's foreground widget in a run in the main axis.
finalinherited
foregroundStyle → TextStyle?
The style to be applied to the sheet's label.
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
height → double?
The vertical extent of the sheet widget.
finalinherited
iconColor → Color?
Color to be used for the icon's inside the sheet.
finalinherited
iconOpacity → double?
Opacity to be apply to iconColor.
finalinherited
iconSize → double?
The size of the icon's inside the sheet, in logical pixels.
finalinherited
isElevated → bool
Whether or not this is elevated variant
no setterinherited
isFilled → bool
Whether or not this is filled variant
no setterinherited
isOutlined → bool
Whether or not this is outlined variant
no setterinherited
isText → bool
Whether or not this is text variant
no setterinherited
isTonal → bool
Whether or not this is tonal variant
no setterinherited
margin → EdgeInsetsGeometry?
Empty space to surround the outside sheet.
finalinherited
overlayColor → Color?
Defines the overlay colors.
finalinherited
overlayDisabled → bool?
Whether the overlay is disabled or not
finalinherited
padding → EdgeInsetsGeometry?
The padding between the contents of the sheet and the outside sheet.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
severity → SheetSeverity?
Type of the sheet severity
finalinherited
shadowColor → Color?
When elevation is non zero the color to use for the sheet's shadow color.
finalinherited
shape → BoxShape?
The type of shape.
finalinherited
surfaceTint → Color?
The color used as an overlay on color to indicate elevation.
finalinherited
variant → SheetVariant?
Type of the sheet variant
finalinherited
width → double?
The horizontal extent of the sheet widget.
finalinherited

Methods

copyWith({ChipVariant? variant, ChipSeverity? severity, double? width, double? height, EdgeInsetsGeometry? margin, EdgeInsetsGeometry? padding, Alignment? alignment, Clip? clipBehavior, bool? overlayDisabled, Color? overlayColor, Color? shadowColor, Color? surfaceTint, double? elevation, TextStyle? foregroundStyle, Color? foregroundColor, double? foregroundOpacity, int? foregroundAlpha, double? foregroundSpacing, bool? foregroundLoosen, bool? foregroundExpanded, CrossAxisAlignment? foregroundAlign, MainAxisAlignment? foregroundJustify, Color? backgroundColor, double? backgroundOpacity, int? backgroundAlpha, Color? borderColor, double? borderOpacity, int? borderAlpha, double? borderWidth, BorderRadius? borderRadius, BorderStyle? borderStyle, BoxShape? shape, Color? iconColor, double? iconOpacity, double? iconSize, AvatarStyle? avatarStyle, Color? checkmarkColor, double? checkmarkSize, double? checkmarkWeight, StrokeStyle? checkmarkStyle, bool? mergeResolved, ChipStyle? selectedStyle, ChipStyle? disabledStyle, ChipStyle? hoveredStyle, ChipStyle? focusedStyle, ChipStyle? pressedStyle}) → ChipStyle
Creates a copy of this ChipStyle but with the given fields replaced with the new values.
override
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
merge(covariant ChipStyle? other) → ChipStyle
Creates a copy of this ChipStyle but with the given fields replaced with the new values.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toMap() → Map<String, dynamic>
override
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringShort() → String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

lerp(ChipStyle? a, ChipStyle? b, double t) → ChipStyle?
Linearly interpolate between two ChipStyle objects.
override