ChipThemeData class

Defines the visual properties of Chip.

Descendant widgets obtain the current ChipThemeData object using ChipTheme.of(context). Instances of ChipThemeData can be customized with ChipThemeData.copyWith or ChipThemeData.merge.

Inheritance
Mixed-in types
Implementers
Annotations

Constructors

ChipThemeData({required Curve curve, required Duration duration, required ChipStyle style, IconData deleteIcon = fallbackDeleteIcon, ChipStyleByVariant variantStyle = const {}, ChipStyleByVariant dangerStyle = const {}, ChipStyleByVariant warningStyle = const {}, ChipStyleByVariant successStyle = const {}, ChipStyleByVariant infoStyle = const {}})
Creates a theme data that can be used for ChipTheme.
const
ChipThemeData.defaults(BuildContext context)
A ChipThemeData with default values.
factory
ChipThemeData.from([ChipThemeData? other])
Creates a ChipThemeData from another one that probably null.
ChipThemeData.ios(BuildContext context)
A ChipThemeData with ios default values.
factory
ChipThemeData.m2(BuildContext context)
A ChipThemeData with material 2 default values.
factory
ChipThemeData.m3(BuildContext context)
A ChipThemeData with material 3 default values.
factory

Properties

curve → Curve
The curve to apply when animating the parameters of Chip widget.
final
dangerStyle → ChipStyleByVariant
The ChipStyle to be applied to the sheet widget with danger severity
final
deleteIcon → IconData
The icon displayed when onDeleted is set.
final
duration → Duration
The duration over which to animate the parameters of Chip widget.
final
hashCode → int
The hash code for this object.
no setteroverride
infoStyle → ChipStyleByVariant
The ChipStyle to be applied to the sheet widget with info severity
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
severityStyle → Map<ChipSeverity, ChipStyleByVariant>
The ChipStyle to be applied to the sheet widget with severity
no setter
style → ChipStyle
The ChipStyle to be applied to the Chip widget
final
successStyle → ChipStyleByVariant
The ChipStyle to be applied to the sheet widget with success severity
final
type → Object
The extension's type.
no setterinherited
variantStyle → ChipStyleByVariant
The ChipStyle to be applied to the variant sheet widget
final
warningStyle → ChipStyleByVariant
The ChipStyle to be applied to the sheet widget with warning severity
final

Methods

copyWith({Curve? curve, Duration? duration, IconData? deleteIcon, ChipStyle? style, ChipStyleByVariant? variantStyle, ChipStyleByVariant? dangerStyle, ChipStyleByVariant? warningStyle, ChipStyleByVariant? successStyle, ChipStyleByVariant? infoStyle}) → ChipThemeData
Creates a copy of this ChipThemeData but with the given fields replaced with the new values.
override
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
override
lerp(covariant ThemeExtension<ChipThemeData>? other, double t) → ChipThemeData
Linearly interpolate with another ThemeExtension object.
override
merge(ChipThemeData? other) → ChipThemeData
Creates a copy of this ChipThemeData but with the given fields replaced with the new values.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resolve({ChipVariant? variant, ChipSeverity? severity}) → ChipStyle
Return ChipStyle that depends on variant and severity
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toMap() → Map<String, dynamic>
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringShort() → String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override

Constants

fallback → const ChipThemeData
Create a ChipThemeData with some reasonable default values.
fallbackDeleteIcon → const IconData
The default icon displayed when onDeleted is set.