ChipThemeDefaults class

Inheritance
Mixed-in types
Annotations

Constructors

ChipThemeDefaults(BuildContext context, [ChipThemeData? other])

Properties

appTheme → ThemeData
no setterinherited
colorTheme → ColorThemeDefaults
no setterinherited
context → BuildContext
final
curve → Curve
The curve to apply when animating the parameters of Chip widget.
finalinherited
dangerStyle → ChipStyleByVariant
The ChipStyle to be applied to the sheet widget with danger severity
finalinherited
deleteIcon → IconData
The icon displayed when onDeleted is set.
finalinherited
duration → Duration
The duration over which to animate the parameters of Chip widget.
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
infoStyle → ChipStyleByVariant
The ChipStyle to be applied to the sheet widget with info severity
finalinherited
isDark → bool
no setterinherited
isLight → bool
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
severityStyle → Map<ChipSeverity, ChipStyleByVariant>
The ChipStyle to be applied to the sheet widget with severity
no setterinherited
style → ChipStyle
The ChipStyle to be applied to the Chip widget
no setteroverride
successStyle → ChipStyleByVariant
The ChipStyle to be applied to the sheet widget with success severity
finalinherited
textTheme → TextTheme
no setterinherited
type → Object
The extension's type.
no setterinherited
variantStyle → ChipStyleByVariant
The ChipStyle to be applied to the variant sheet widget
no setteroverride
warningStyle → ChipStyleByVariant
The ChipStyle to be applied to the sheet widget with warning severity
finalinherited

Methods

copyWith({Curve? curve, Duration? duration, IconData? deleteIcon, ChipStyle? style, ChipStyleByVariant? variantStyle, ChipStyleByVariant? dangerStyle, ChipStyleByVariant? warningStyle, ChipStyleByVariant? successStyle, ChipStyleByVariant? infoStyle}) → ChipThemeData
Creates a copy of this ChipThemeData but with the given fields replaced with the new values.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
lerp(covariant ThemeExtension<ChipThemeData>? other, double t) → ChipThemeData
Linearly interpolate with another ThemeExtension object.
inherited
merge(ChipThemeData? other) → ChipThemeData
Creates a copy of this ChipThemeData but with the given fields replaced with the new values.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resolve({ChipVariant? variant, ChipSeverity? severity}) → ChipStyle
Return ChipStyle that depends on variant and severity
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toMap() → Map<String, dynamic>
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringShort() → String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited