ChoiceController<T> class

Inheritance

Constructors

ChoiceController({List<T> value = const [], List<T> items = const [], ValueChanged<List<T>>? onChanged, bool multiple = false, bool mandatory = false})

Properties

hashCode → int
The hash code for this object.
no setterinherited
hasListeners → bool
Whether any listeners are currently registered.
no setterinherited
isChecked → bool
no setter
isEmpty → bool
no setter
isIndeterminate → bool
no setter
isNotEmpty → bool
no setter
items → List<T>
final
length → int
no setter
mandatory → bool
will always have a value
final
multiple → bool
allow to select multiple values
final
onChanged → ValueChanged<List<T>>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → List<T>
no setter

Methods

add(T item) → void
Mutator to mark a T value as active.
addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
clear() → void
dispose() → void
Discards any resources used by the object.
inherited
fill() → void
has(T value) → bool
hasAny(List<T> value) → bool
hasEvery(List<T> value) → bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
remove(T item) → void
Mutator to mark a T value as inactive.
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
replace(List<T> value) → void
select(T item, {ValueChanged<bool>? onChanged}) → ValueChanged<bool>
selectAll({ValueChanged<bool>? onChanged}) → ValueChanged<bool>
toggle(T item, [bool? active]) → void
Mutator to mark a T value as either active or inactive.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited