ColorThemeDefaults class

Inheritance
Mixed-in types
Annotations

Constructors

ColorThemeDefaults(BuildContext context, [ColorThemeData? other])

Properties

appTheme → ThemeData
no setterinherited
background → Color
no setter
brightness → Brightness
no setter
colorTheme → ColorThemeDefaults
no setterinherited
context → BuildContext
final
danger → Color
The Color to be applied to the alert widget
finalinherited
error → Color
no setter
errorContainer → Color
no setter
hashCode → int
The hash code for this object.
no setterinherited
info → Color
The Color to be applied to the alert widget
finalinherited
inversePrimary → Color
no setter
inverseSurface → Color
no setter
isDark → bool
no setterinherited
isLight → bool
no setterinherited
onError → Color
no setter
onErrorContainer → Color
no setter
onInverseSurface → Color
no setter
onPrimary → Color
no setter
onPrimaryContainer → Color
no setter
onSecondary → Color
no setter
onSecondaryContainer → Color
no setter
onSurface → Color
no setter
onSurfaceVariant → Color
no setter
onTertiary → Color
no setter
onTertiaryContainer → Color
no setter
outline → Color
no setter
primary → Color
no setter
primaryContainer → Color
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
secondary → Color
no setter
secondaryContainer → Color
no setter
shadow → Color
no setter
success → Color
The Color to be applied to the alert widget
finalinherited
surface → Color
no setter
surfaceTint → Color
no setter
surfaceVariant → Color
no setter
tertiary → Color
no setter
tertiaryContainer → Color
no setter
textTheme → TextTheme
no setterinherited
type → Object
The extension's type.
no setterinherited
unselectedWidgetColor → Color
no setter
warning → Color
The Color to be applied to the alert widget
finalinherited

Methods

copyWith({Color? danger, Color? warning, Color? success, Color? info}) → ColorThemeData
Creates a copy of this ColorThemeData but with the given fields replaced with the new values.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
lerp(covariant ThemeExtension<ColorThemeData>? other, double t) → ColorThemeData
Linearly interpolate with another ThemeExtension object.
inherited
merge(ColorThemeData? other) → ColorThemeData
Creates a copy of this ColorThemeData but with the given fields replaced with the new values.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toMap() → Map<String, dynamic>
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringShort() → String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited