DrivenRadioStyle class

Create a RadioStyle that handle the widget events

Inheritance
Implemented types

Constructors

DrivenRadioStyle({double? size, BoxShape? shape, EdgeInsetsGeometry? margin, EdgeInsetsGeometry? padding, Color? backgroundColor, double? backgroundOpacity, int? backgroundAlpha, Color? borderColor, double? borderOpacity, int? borderAlpha, double? borderWidth, BorderRadiusGeometry? borderRadius, BorderStyle? borderStyle, double? thumbInset, Color? thumbColor, double? thumbOpacity, int? thumbAlpha, Color? overlayColor, double? overlayOpacity, bool? overlayDisabled, double? overlayRadius, RadioStyle? selectedStyle, RadioStyle? focusedStyle, RadioStyle? hoveredStyle, RadioStyle? pressedStyle, RadioStyle? disabledStyle, bool? mergeResolved})
const
DrivenRadioStyle.from(RadioStyle? enabledStyle, {RadioStyle? selectedStyle, RadioStyle? focusedStyle, RadioStyle? hoveredStyle, RadioStyle? pressedStyle, RadioStyle? disabledStyle, bool? mergeResolved})
Create a DrivenRadioStyle with value from another RadioStyle.
DrivenRadioStyle.resolver(DrivenPropertyResolver<RadioStyle?> resolver, {bool? mergeResolved = false})
Create a DrivenRadioStyle from a resolver callback

Properties

backgroundAlpha → int?
Alpha to be apply to backgroundColor.
finalinherited
backgroundColor → Color?
Color to be used for the radio's background.
finalinherited
backgroundOpacity → double?
Opacity to be apply to backgroundColor.
finalinherited
borderAlpha → int?
Alpha to be apply to borderColor.
finalinherited
borderColor → Color?
Color to be used for the radio's border.
finalinherited
borderOpacity → double?
Opacity to be apply to borderColor.
finalinherited
borderRadius → BorderRadiusGeometry?
The radii for each corner of the radio's border.
finalinherited
borderStyle → BorderStyle?
The style of this side of the radio's border.
finalinherited
borderWidth → double?
The width of this side of the radio's border, in logical pixels.
finalinherited
disabledStyle → RadioStyle?
The style to be resolved when events includes RadioEvent.disabled.
final
driven → Map<WidgetEvent, RadioStyle?>
Map of driven style, order matters
no setter
focusedStyle → RadioStyle?
The style to be resolved when events includes RadioEvent.focused.
final
hashCode → int
The hash code for this object.
no setterinherited
hoveredStyle → RadioStyle?
The style to be resolved when events includes RadioEvent.hovered.
final
margin → EdgeInsetsGeometry?
Empty space to surround the outside clickable area.
finalinherited
mergeResolved → bool?
Whether the resolved style is merged to the previous resolved style or not
final
overlayColor → Color?
The overlay color when pressed, hovered over, or focused.
finalinherited
overlayDisabled → bool?
Whether the overlay is disabled or not,
finalinherited
overlayOpacity → double?
The overlay opacity when pressed, hovered over, or focused.
finalinherited
overlayRadius → double?
The radius of the overlay.
finalinherited
padding → EdgeInsetsGeometry?
Empty space to increase the clickable area.
finalinherited
pressedStyle → RadioStyle?
The style to be resolved when events includes RadioEvent.pressed.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
selectedStyle → RadioStyle?
The style to be resolved when events includes RadioEvent.selected.
final
shape → BoxShape?
Type of the radio border shape.
finalinherited
size → double?
The size of the radio in logical pixels.
finalinherited
thumbAlpha → int?
Alpha to be apply to thumbColor.
finalinherited
thumbColor → Color?
The Color to be apply to the radio's thumb.
finalinherited
thumbInset → double?
finalinherited
thumbOpacity → double?
Opacity to be apply to thumbColor.
finalinherited

Methods

copyWith({double? size, BoxShape? shape, EdgeInsetsGeometry? margin, EdgeInsetsGeometry? padding, Color? backgroundColor, double? backgroundOpacity, int? backgroundAlpha, Color? borderColor, double? borderOpacity, int? borderAlpha, double? borderWidth, BorderRadiusGeometry? borderRadius, BorderStyle? borderStyle, double? thumbInset, Color? thumbColor, double? thumbOpacity, int? thumbAlpha, Color? overlayColor, double? overlayOpacity, bool? overlayDisabled, double? overlayRadius, bool? mergeResolved, RadioStyle? selectedStyle, RadioStyle? focusedStyle, RadioStyle? hoveredStyle, RadioStyle? pressedStyle, RadioStyle? disabledStyle}) → DrivenRadioStyle
Creates a copy of this DrivenRadioStyle but with the given fields replaced with the new values.
override
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
override
merge(RadioStyle? other) → RadioStyle
Creates a copy of this RadioStyle but with the given fields replaced with the new values.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resolve(Set<WidgetEvent> events) → RadioStyle
Returns a value of type T that depends on events.
override
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toMap() → Map<String, dynamic>
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringShort() → String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

evaluate(RadioStyle? value, Set<WidgetEvent> events) → RadioStyle?
Resolves the value for the given set of events if value is an event driven RadioStyle, otherwise returns the value itself.
override