ListTileThemeDefaults class

Inheritance
Mixed-in types
Annotations

Constructors

ListTileThemeDefaults(BuildContext context, [ListTileThemeData? other])

Properties

appTheme → ThemeData
no setterinherited
colorTheme → ColorThemeDefaults
no setterinherited
context → BuildContext
final
hashCode → int
The hash code for this object.
no setterinherited
isDark → bool
no setterinherited
isLight → bool
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
style → ListTileStyle
The ListTileStyle to be applied to the ListTile widget
no setteroverride
textTheme → TextTheme
no setterinherited
type → Object
The extension's type.
no setterinherited

Methods

copyWith({ListTileStyle? style}) → ListTileThemeData
Creates a copy of this ListTileThemeData but with the given fields replaced with the new values.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
lerp(covariant ThemeExtension<ListTileThemeData>? other, double t) → ListTileThemeData
Linearly interpolate with another ThemeExtension object.
inherited
merge(ListTileThemeData? other) → ListTileThemeData
Creates a copy of this ListTileThemeData but with the given fields replaced with the new values.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toMap() → Map<String, dynamic>
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringShort() → String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited