MenuItem class

Implementers

Constructors

Properties

hashCode → int
The hash code for this object.
no setterinherited
name → String
final
onPressed → VoidCallback?
final
padding → EdgeInsetsGeometry?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
spacing → double
final
trailing → Widget?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited