Sheet class

The sheet widget is the baseline for numerous components.

Inheritance
Implementers

Constructors

Sheet({Key? key, Duration? duration, Curve? curve, SheetVariant? variant, SheetSeverity? severity, double? width, double? height, EdgeInsetsGeometry? margin, EdgeInsetsGeometry? padding, Alignment? alignment, Clip? clipBehavior, Color? overlayColor, Color? shadowColor, double? elevation, TextStyle? foregroundStyle, Color? foregroundColor, double? foregroundOpacity, int? foregroundAlpha, double? foregroundSpacing, Color? backgroundColor, double? backgroundOpacity, int? backgroundAlpha, Color? borderColor, double? borderOpacity, int? borderAlpha, double? borderWidth, BorderRadius? borderRadius, BorderStyle? borderStyle, BoxShape? shape, Color? iconColor, double? iconOpacity, double? iconSize, SheetStyle? style, String? tooltip, Widget? child})
const
Sheet.circle({Key? key, double? radius, Duration? duration, Curve? curve, SheetVariant? variant, SheetSeverity? severity, EdgeInsetsGeometry? margin, EdgeInsetsGeometry? padding, Alignment? alignment, Clip? clipBehavior, Color? overlayColor, Color? shadowColor, double? elevation, TextStyle? foregroundStyle, Color? foregroundColor, double? foregroundOpacity, int? foregroundAlpha, double? foregroundSpacing, Color? backgroundColor, double? backgroundOpacity, int? backgroundAlpha, Color? borderColor, double? borderOpacity, int? borderAlpha, double? borderWidth, BorderRadius? borderRadius, BorderStyle? borderStyle, Color? iconColor, double? iconOpacity, double? iconSize, SheetStyle? style, String? tooltip, Widget? child})
const
Sheet.danger({Key? key, Duration? duration, Curve? curve, SheetVariant? variant, double? width, double? height, EdgeInsetsGeometry? margin, EdgeInsetsGeometry? padding, Alignment? alignment, Clip? clipBehavior, Color? overlayColor, Color? shadowColor, double? elevation, TextStyle? foregroundStyle, Color? foregroundColor, double? foregroundOpacity, int? foregroundAlpha, double? foregroundSpacing, Color? backgroundColor, double? backgroundOpacity, int? backgroundAlpha, Color? borderColor, double? borderOpacity, int? borderAlpha, double? borderWidth, BorderRadius? borderRadius, BorderStyle? borderStyle, BoxShape? shape, Color? iconColor, double? iconOpacity, double? iconSize, SheetStyle? style, String? tooltip, Widget? child})
const
Sheet.info({Key? key, Duration? duration, Curve? curve, SheetVariant? variant, double? width, double? height, EdgeInsetsGeometry? margin, EdgeInsetsGeometry? padding, Alignment? alignment, Clip? clipBehavior, Color? overlayColor, Color? shadowColor, double? elevation, TextStyle? foregroundStyle, Color? foregroundColor, double? foregroundOpacity, int? foregroundAlpha, double? foregroundSpacing, Color? backgroundColor, double? backgroundOpacity, int? backgroundAlpha, Color? borderColor, double? borderOpacity, int? borderAlpha, double? borderWidth, BorderRadius? borderRadius, BorderStyle? borderStyle, BoxShape? shape, Color? iconColor, double? iconOpacity, double? iconSize, SheetStyle? style, String? tooltip, Widget? child})
const
Sheet.square({Key? key, double? size, Duration? duration, Curve? curve, SheetVariant? variant, SheetSeverity? severity, EdgeInsetsGeometry? margin, EdgeInsetsGeometry? padding, Alignment? alignment, Clip? clipBehavior, Color? overlayColor, Color? shadowColor, double? elevation, TextStyle? foregroundStyle, Color? foregroundColor, double? foregroundOpacity, int? foregroundAlpha, double? foregroundSpacing, Color? backgroundColor, double? backgroundOpacity, int? backgroundAlpha, Color? borderColor, double? borderOpacity, int? borderAlpha, double? borderWidth, BorderRadius? borderRadius, BorderStyle? borderStyle, Color? iconColor, double? iconOpacity, double? iconSize, BoxShape? shape, SheetStyle? style, String? tooltip, Widget? child})
const
Sheet.success({Key? key, Duration? duration, Curve? curve, SheetVariant? variant, double? width, double? height, EdgeInsetsGeometry? margin, EdgeInsetsGeometry? padding, Alignment? alignment, Clip? clipBehavior, Color? overlayColor, Color? shadowColor, double? elevation, TextStyle? foregroundStyle, Color? foregroundColor, double? foregroundOpacity, int? foregroundAlpha, double? foregroundSpacing, Color? backgroundColor, double? backgroundOpacity, int? backgroundAlpha, Color? borderColor, double? borderOpacity, int? borderAlpha, double? borderWidth, BorderRadius? borderRadius, BorderStyle? borderStyle, BoxShape? shape, Color? iconColor, double? iconOpacity, double? iconSize, SheetStyle? style, String? tooltip, Widget? child})
const
Sheet.warning({Key? key, Duration? duration, Curve? curve, SheetVariant? variant, double? width, double? height, EdgeInsetsGeometry? margin, EdgeInsetsGeometry? padding, Alignment? alignment, Clip? clipBehavior, Color? overlayColor, Color? shadowColor, double? elevation, TextStyle? foregroundStyle, Color? foregroundColor, double? foregroundOpacity, int? foregroundAlpha, double? foregroundSpacing, Color? backgroundColor, double? backgroundOpacity, int? backgroundAlpha, Color? borderColor, double? borderOpacity, int? borderAlpha, double? borderWidth, BorderRadius? borderRadius, BorderStyle? borderStyle, BoxShape? shape, Color? iconColor, double? iconOpacity, double? iconSize, SheetStyle? style, String? tooltip, Widget? child})
const

Properties

alignment → Alignment?
Align the child within the sheet.
final
backgroundAlpha → int?
Alpha to be apply to backgroundColor.
final
backgroundColor → Color?
Color to be used for the sheet's background.
final
backgroundOpacity → double?
Opacity to be apply to backgroundColor.
final
borderAlpha → int?
Alpha to be apply to borderColor.
final
borderColor → Color?
Color to be used for the sheet's border.
final
borderOpacity → double?
Opacity to be apply to borderColor.
final
borderRadius → BorderRadius?
The radii for each corner of the sheet's border.
final
borderStyle → BorderStyle?
The style of this side of the sheet's border.
final
borderWidth → double?
The width of this side of the sheet's border, in logical pixels.
final
child → Widget?
The widget below this widget in the tree.
final
clipBehavior → Clip?
The sheet's content will be clipped (or not) according to this option.
final
curve → Curve?
The curve to apply when animating the parameters of this widget.
final
duration → Duration?
The duration over which to animate the parameters of this widget.
final
effectiveStyle → SheetStyle
no setter
elevation → double?
The sheet's z-coordinate relative to the parent at which to place this physical object.
final
foregroundAlpha → int?
Alpha to be apply to foregroundColor.
final
foregroundColor → Color?
The color to be applied to the sheet's label, and icon
final
foregroundOpacity → double?
Opacity to be apply to foregroundColor.
final
foregroundSpacing → double?
How much space to place between sheet's foreground widget in a run in the main axis.
final
foregroundStyle → TextStyle?
The style to be applied to the sheet's label.
final
hashCode → int
The hash code for this object.
no setterinherited
height → double?
The vertical extent of the sheet widget.
final
iconColor → Color?
Color to be used for the icon's inside the sheet.
final
iconOpacity → double?
Opacity to be apply to iconColor.
final
iconSize → double?
The size of the icon's inside the sheet, in logical pixels.
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
margin → EdgeInsetsGeometry?
Empty space to surround the outside sheet.
final
overlayColor → Color?
Defines the overlay colors.
final
padding → EdgeInsetsGeometry?
The padding between the contents of the sheet and the outside sheet.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
severity → SheetSeverity?
Type of the sheet severity
final
shadowColor → Color?
When elevation is non zero the color to use for the sheet's shadow color.
final
shape → BoxShape?
The type of shape.
final
style → SheetStyle?
The style to be applied to the sheet.
final
tooltip → String?
Tooltip string to be used for the body area of the button.
final
variant → SheetVariant?
Type of the sheet variant
final
width → double?
The horizontal extent of the sheet widget.
final

Methods

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited