SheetThemeDefaults class

Inheritance
Mixed-in types
Annotations

Constructors

SheetThemeDefaults(BuildContext context, [SheetThemeData? other])

Properties

appTheme → ThemeData
no setterinherited
colorTheme → ColorThemeDefaults
no setterinherited
context → BuildContext
final
curve → Curve
The curve to apply when animating the parameters of sheet widget.
finalinherited
dangerStyle → SheetStyleByVariant
The SheetStyle to be applied to the sheet widget with danger severity
finalinherited
duration → Duration
The duration over which to animate the parameters of sheet widget.
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
infoStyle → SheetStyleByVariant
The SheetStyle to be applied to the sheet widget with info severity
finalinherited
isDark → bool
no setterinherited
isLight → bool
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
severityStyle → Map<SheetSeverity, SheetStyleByVariant>
The SheetStyle to be applied to the sheet widget with severity
no setterinherited
style → SheetStyle
The SheetStyle to be applied to the sheet widget
finalinherited
successStyle → SheetStyleByVariant
The SheetStyle to be applied to the sheet widget with success severity
finalinherited
textTheme → TextTheme
no setterinherited
type → Object
The extension's type.
no setterinherited
variantStyle → SheetStyleByVariant
The SheetStyle to be applied to the variant sheet widget
no setteroverride
warningStyle → SheetStyleByVariant
The SheetStyle to be applied to the sheet widget with warning severity
finalinherited

Methods

copyWith({Curve? curve, Duration? duration, SheetStyle? style, SheetStyleByVariant? variantStyle, SheetStyleByVariant? dangerStyle, SheetStyleByVariant? warningStyle, SheetStyleByVariant? successStyle, SheetStyleByVariant? infoStyle}) → SheetThemeData
Creates a copy of this SheetThemeData but with the given fields replaced with the new values.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
lerp(covariant ThemeExtension<SheetThemeData>? other, double t) → SheetThemeData
Linearly interpolate with another ThemeExtension object.
inherited
merge(SheetThemeData? other) → SheetThemeData
Creates a copy of this SheetThemeData but with the given fields replaced with the new values.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resolve({SheetVariant? variant, SheetSeverity? severity}) → SheetStyle
Return SheetStyle that depends on variant and severity
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toMap() → Map<String, dynamic>
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringShort() → String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited