Switch class

Switches toggle the state of a single setting on or off.

Inheritance

Constructors

Switch({Key? key, SwitchStyle? style, String? tooltip, ValueChanged<bool>? onChanged, bool selected = false, bool indeterminate = false, bool disabled = false, bool autofocus = false, FocusNode? focusNode, SwitchEventController? eventsController, Curve? curve, Duration? duration})
const

Properties

autofocus → bool
True if this widget will be selected as the initial focus when no other node in its scope is currently focused.
final
curve → Curve?
The curve to apply when animating the parameters of this widget.
final
disabled → bool
Whether or not this switch is disabled for input.
final
duration → Duration?
The duration over which to animate the parameters of this widget.
final
eventsController → SwitchEventController?
Used by widgets that expose their internal event for the sake of extensions that add support for additional events.
final
focusNode → FocusNode?
An optional focus node to use as the focus node for this widget.
final
hashCode → int
The hash code for this object.
no setterinherited
indeterminate → bool
Whether or not this switch is indeterminate.
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onChanged → ValueChanged<bool>?
Called when the chip should change between selected and de-selected states.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
selected → bool
Whether or not this switch is selected.
final
style → SwitchStyle?
The style to be applied to the switch.
final
tooltip → String?
Tooltip string to be used for the body area of the switch.
final

Methods

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited