SwitchTileThemeDefaults class

Inheritance
Mixed-in types
Annotations

Constructors

SwitchTileThemeDefaults(BuildContext context, [SwitchTileThemeData? other])

Properties

appTheme → ThemeData
no setterinherited
buttonStyle → ButtonStyle
The ButtonStyle to be applied to the clickable area.
finalinherited
colorTheme → ColorThemeDefaults
no setterinherited
context → BuildContext
final
controlAffinity → ControlAffinity
Where to place the control next to a label.
finalinherited
curve → Curve
The curve to apply when animating the parameters of switch tile widget.
finalinherited
duration → Duration
The duration over which to animate the parameters of switch tile widget.
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
isDark → bool
no setterinherited
isLight → bool
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
switchStyle → SwitchStyle
The SwitchStyle to be applied to the switch tile widget
finalinherited
textTheme → TextTheme
no setterinherited
type → Object
The extension's type.
no setterinherited

Methods

copyWith({Curve? curve, Duration? duration, ControlAffinity? controlAffinity, SwitchStyle? switchStyle, ButtonStyle? buttonStyle}) → SwitchTileThemeData
Creates a copy of this SwitchTileThemeData but with the given fields replaced with the new values.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
lerp(covariant ThemeExtension<SwitchTileThemeData>? other, double t) → SwitchTileThemeData
Linearly interpolate with another ThemeExtension object.
inherited
merge(SwitchTileThemeData? other) → SwitchTileThemeData
Creates a copy of this SwitchTileThemeData but with the given fields replaced with the new values.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toMap() → Map<String, dynamic>
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringShort() → String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited