ToggleIconStyle class

The style to be applied to ToggleIcon widget

Mixed-in types
Implementers
Annotations

Constructors

ToggleIconStyle({double? size, Color? backColor, double? backOpacity, Color? color, double? opacity, double? scale})
Create a style to be applied to ToggleIcon widget
const
ToggleIconStyle.from(ToggleIconStyle? other)
Create an ToggleIconStyle from another style

Properties

backColor → Color?
The color to use when drawing the back icon.
final
backOpacity → double?
Opacity to be apply to backColor.
final
color → Color?
The color to use when drawing the icon.
final
hashCode → int
The hash code for this object.
no setteroverride
opacity → double?
Opacity to be apply to color.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scale → double?
Scale the size of the icon.
final
size → double?
The size of the icon in logical pixels.
final

Methods

copyWith({double? size, Color? color, double? opacity, double? scale, Color? backColor, double? backOpacity, bool? mergeResolved, ToggleIconStyle? selectedStyle, ToggleIconStyle? disabledStyle}) → ToggleIconStyle
Creates a copy of this ToggleIconStyle but with the given fields replaced with the new values.
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
override
merge(ToggleIconStyle? other) → ToggleIconStyle
Creates a copy of this ToggleIconStyle but with the given fields replaced with the new values.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toMap() → Map<String, dynamic>
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringShort() → String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override

Static Methods

lerp(ToggleIconStyle? a, ToggleIconStyle? b, double t) → ToggleIconStyle?
Linearly interpolate between two ToggleIconStyle objects.