TonalToggleButton class

A tonal button is an alternative middle ground between filled and outlined buttons. They’re useful in contexts where a lower-priority button requires slightly more emphasis than an outline would give, such as "Next" in an onboarding flow. Tonal buttons use the secondary color mapping.

Inheritance

Constructors

TonalToggleButton({Key? key, ButtonSeverity? severity, bool selected = false, bool loading = false, bool disabled = false, bool autofocus = false, FocusNode? focusNode, ValueChanged<bool>? onSelected, ButtonEventController? eventsController, Curve? curve, Duration? duration, ButtonStyle? enabledStyle, ButtonStyle? selectedStyle, ButtonStyle? focusedStyle, ButtonStyle? hoveredStyle, ButtonStyle? pressedStyle, ButtonStyle? disabledStyle, String? tooltip, Widget? leading, Widget? trailing, required Widget child})
Create a tonal button
const
TonalToggleButton.block({Key? key, ButtonSeverity? severity, CrossAxisAlignment? alignChildren, MainAxisAlignment? justifyChildren, bool expanded = true, bool selected = false, bool loading = false, bool disabled = false, bool autofocus = false, FocusNode? focusNode, ValueChanged<bool>? onSelected, ButtonEventController? eventsController, Curve? curve, Duration? duration, ButtonStyle? enabledStyle, ButtonStyle? selectedStyle, ButtonStyle? focusedStyle, ButtonStyle? hoveredStyle, ButtonStyle? pressedStyle, ButtonStyle? disabledStyle, String? tooltip, Widget? leading, Widget? trailing, required Widget child})
Create a block tonal button
TonalToggleButton.icon({Key? key, ButtonSeverity? severity, BoxShape shape = BoxShape.circle, double? size, bool selected = false, bool loading = false, bool disabled = false, bool autofocus = false, FocusNode? focusNode, ValueChanged<bool>? onSelected, ButtonEventController? eventsController, Curve? curve, Duration? duration, ButtonStyle? enabledStyle, ButtonStyle? selectedStyle, ButtonStyle? focusedStyle, ButtonStyle? hoveredStyle, ButtonStyle? pressedStyle, ButtonStyle? disabledStyle, String? tooltip, Widget? leading, Widget? trailing, required Widget child})
Create an icon tonal button

Properties

additionalStyle → ButtonStyle?
Additional style to be merge with style
finalinherited
autofocus → bool
True if this widget will be selected as the initial focus when no other node in its scope is currently focused.
finalinherited
child → Widget
The widget below this widget in the tree.
finalinherited
curve → Curve?
The curve to apply when animating the parameters of this widget.
finalinherited
disabled → bool
Whether or not this button is disabled for input.
finalinherited
disabledStyle → ButtonStyle?
The style to be applied when events includes WidgetEvent.disabled.
finalinherited
duration → Duration?
The duration over which to animate the parameters of this widget.
finalinherited
effectiveStyle → dynamic
The style merged with additionalStyle
no setterinherited
enabledStyle → ButtonStyle?
The style to be applied when no events occurs.
finalinherited
eventsController → ButtonEventController?
Used by widgets that expose their internal event for the sake of extensions that add support for additional events.
finalinherited
focusedStyle → ButtonStyle?
The style to be applied when events includes WidgetEvent.focused.
finalinherited
focusNode → FocusNode?
An optional focus node to use as the focus node for this widget.
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
hoveredStyle → ButtonStyle?
The style to be applied when events includes WidgetEvent.hovered.
finalinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
leading → Widget?
A custom widget to display prior to the button's child.
finalinherited
loading → bool
Whether or not this button is in loading state.
finalinherited
onSelected → ValueChanged<bool>?
Called when the button should change between selected and de-selected states.
finalinherited
pressedStyle → ButtonStyle?
The style to be applied when events includes WidgetEvent.pressed.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
selected → bool
Whether or not this button is selected.
finalinherited
selectedStyle → ButtonStyle?
The style to be applied when events includes WidgetEvent.selected.
finalinherited
severity → ButtonSeverity?
Type of the button severity
finalinherited
style → ButtonStyle?
The style to be applied to the button.
no setterinherited
tooltip → String?
Tooltip string to be used for the body area of the button.
finalinherited
trailing → Widget?
A custom widget to display next to the button's child.
finalinherited
variant → ButtonVariant?
Type of the button variant
no setteroverride

Methods

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
inherited
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited